==> babel-plugin-extract-gql-3.0.3.tgz: package/lib/index.js <==
"use strict";

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i["return"] && (_r = _i["return"](), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
var fs = require('fs');
var path = require('path');
var crypto = require('crypto');
var pkgDir = require('pkg-dir');
var pkgRoot = pkgDir.sync();
var outputFile = path.join(pkgRoot, 'gql-queries.json');
function appendJSON(json) {
  var data = {};
  if (fs.existsSync(outputFile)) {
    try {
      data = JSON.parse(fs.readFileSync(outputFile, 'utf8') || '');
    } catch (e) {
      console.log(e);
    }
  }
  Object.assign(data, json);
  fs.writeFileSync(outputFile, JSON.stringify(data, null, 2));
}
function extractGql(_ref) {
  var t = _ref.types;
  var queries = {};
  var varsTransformed = {};
  return {
    pre: function pre() {
      this.queries = {};
    },
    visitor: {
      TaggedTemplateExpression: function TaggedTemplateExpression(path) {
        var _path$node = path.node,
          tag = _path$node.tag,
          quasi = _path$node.quasi;
        if (tag.name !== 'persist') return; // if not the gql query, ignore
        if (quasi.quasis.length > 1) return; // if dynamic string, ignore

        var queryText = quasi.quasis[0].value.cooked.trim();
        var queryHash = crypto.createHash('sha256').update(queryText).digest('hex');
        var queryHashNode = t.stringLiteral(queryHash);
        this.queries[queryHash] = queryText;
        queries[queryHash] = queryText;
        var varName = path.parentPath.node.id.name;
        varsTransformed[varName] = true;
        path.replaceWith(queryHashNode);
      },
      CallExpression: function CallExpression(path) {
        var _path$node2 = path.node,
          callee = _path$node2.callee,
          args = _path$node2.arguments;
        var _args = _slicedToArray(args, 2),
          varNameArg = _args[0],
          optionsArg = _args[1];
        var varName = varNameArg.name;

        // if not a call to useQuery OR if is useQuery but not with a persisted query, ignore
        if (callee.name !== 'useQuery' || !varsTransformed[varName]) return;
        var optionsObj = optionsArg || t.objectExpression([]);
        optionsObj.properties.push(t.objectProperty(t.stringLiteral('persisted'), t.booleanLiteral(true)));
        if (!optionsArg) args.push(optionsObj);
      }
    },
    post: function post() {
      appendJSON(this.queries);
    }
  };
}
module.exports = extractGql;

==> babel-plugin-extract-gql-3.0.4.tgz: package/lib/index.js <==
"use strict";

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(r, l) { var t = null == r ? null : "undefined" != typeof Symbol && r[Symbol.iterator] || r["@@iterator"]; if (null != t) { var e, n, i, u, a = [], f = !0, o = !1; try { if (i = (t = t.call(r)).next, 0 === l) { if (Object(t) !== t) return; f = !1; } else for (; !(f = (e = i.call(t)).done) && (a.push(e.value), a.length !== l); f = !0); } catch (r) { o = !0, n = r; } finally { try { if (!f && null != t["return"] && (u = t["return"](), Object(u) !== u)) return; } finally { if (o) throw n; } } return a; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
var fs = require('fs');
var path = require('path');
var crypto = require('crypto');
var pkgDir = require('pkg-dir');
var pkgRoot = pkgDir.sync();
var outputFile = path.join(pkgRoot, 'gql-queries.json');
function appendJSON(json) {
  var data = {};
  if (fs.existsSync(outputFile)) {
    try {
      data = JSON.parse(fs.readFileSync(outputFile, 'utf8') || '');
    } catch (e) {
      console.log(e);
    }
  }
  Object.assign(data, json);
  fs.writeFileSync(outputFile, JSON.stringify(data, null, 2));
}
function extractGql(_ref) {
  var t = _ref.types;
  var queries = {};
  var varsTransformed = {};
  return {
    pre: function pre() {
      this.queries = {};
    },
    visitor: {
      TaggedTemplateExpression: function TaggedTemplateExpression(path) {
        var _path$node = path.node,
          tag = _path$node.tag,
          quasi = _path$node.quasi;
        if (tag.name !== 'persist') return; // if not the gql query, ignore
        if (quasi.quasis.length > 1) return; // if dynamic string, ignore

        var queryText = quasi.quasis[0].value.cooked.trim();
        var queryHash = crypto.createHash('sha256').update(queryText).digest('hex');
        var queryHashNode = t.stringLiteral(queryHash);
        this.queries[queryHash] = queryText;
        queries[queryHash] = queryText;
        var varName = path.parentPath.node.id.name;
        varsTransformed[varName] = true;
        path.replaceWith(queryHashNode);
      },
      CallExpression: function CallExpression(path) {
        var _path$node2 = path.node,
          callee = _path$node2.callee,
          args = _path$node2.arguments;
        var _args = _slicedToArray(args, 2),
          varNameArg = _args[0],
          optionsArg = _args[1];
        var varName = varNameArg.name;

        // if not a call to useQuery OR if is useQuery but not with a persisted query, ignore
        if (callee.name !== 'useQuery' || !varsTransformed[varName]) return;
        var optionsObj = optionsArg || t.objectExpression([]);
        optionsObj.properties.push(t.objectProperty(t.stringLiteral('persisted'), t.booleanLiteral(true)));
        if (!optionsArg) args.push(optionsObj);
      }
    },
    post: function post() {
      appendJSON(this.queries);
    }
  };
}
module.exports = extractGql;
